Crate peace_item_file_download

Crate peace_item_file_download 

Manages downloading a file for the peace framework

Structs

ETag
Represents an ETag returned from a server.
FileDownloadApplyFns
ApplyFns for the file to download.
FileDownloadData
Data used to download a file.
FileDownloadItem
Item for downloading a file.
FileDownloadParams
File download parameters.
FileDownloadParamsFieldWise
Specification of how to look up values for an item’s parameters.
FileDownloadParamsPartial
Item parameters that may not necessarily have values.
FileDownloadState
Newtype wrapper for State<FileDownloadStatePhysical, FetchedOpt<ETag>>.
FileDownloadStateCurrentFn
Reads the current state of the file to download.
FileDownloadStateDiffFn
Download status diff function.
FileDownloadStateGoalFn
Reads the goal state of the file to download.

Enums

FileDownloadError
Error while managing a file download.
FileDownloadStateDiff
Diff between the current and goal downloaded file.
FileDownloadStateLogical
State of the contents of the file to download.

Constants

IN_MEMORY_CONTENTS_MAX
Read up to 1 kB in memory.