Manages downloading a file for the peace framework
Structs
- ETag
- Represents an ETag returned from a server.
- File
Download Apply Fns - ApplyFns for the file to download.
- File
Download Data - Data used to download a file.
- File
Download Item - Item for downloading a file.
- File
Download Params - File download parameters.
- File
Download Params Field Wise - Specification of how to look up values for an item’s parameters.
- File
Download Params Partial - Item parameters that may not necessarily have values.
- File
Download State - Newtype wrapper for
State<FileDownloadStatePhysical, FetchedOpt<ETag>>. - File
Download State Current Fn - Reads the current state of the file to download.
- File
Download State Diff Fn - Download status diff function.
- File
Download State Goal Fn - Reads the goal state of the file to download.
Enums
- File
Download Error - Error while managing a file download.
- File
Download State Diff - Diff between the current and goal downloaded file.
- File
Download State Logical - State of the contents of the file to download.
Constants
- IN_
MEMORY_ CONTENTS_ MAX - Read up to 1 kB in memory.